==> apache-camel-2.24.3-src.zip: apache-camel-2.24.3/components/camel-jbpm/src/main/java/org/apache/camel/component/jbpm/JBPMComponent.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jbpm;

import java.net.URL;
import java.util.Map;

import org.apache.camel.Endpoint;
import org.apache.camel.impl.DefaultComponent;

public class JBPMComponent extends DefaultComponent {

    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        JBPMConfiguration configuration = new JBPMConfiguration();
        if (remaining.startsWith("events")) {
            configuration.setEventListenerType(remaining.split(":")[1]);
        } else {        
            configuration.setConnectionURL(new URL(remaining));
        }
        setProperties(configuration, parameters);
        return new JBPMEndpoint(uri, this, configuration);
    }
}

==> apache-camel-3.4.4-src.zip: apache-camel-3.4.4/components/camel-jbpm/src/main/java/org/apache/camel/component/jbpm/JBPMComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jbpm;

import java.net.URL;
import java.util.Map;

import org.apache.camel.Endpoint;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.DefaultComponent;

@Component("jbpm")
public class JBPMComponent extends DefaultComponent {

    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        JBPMConfiguration configuration = new JBPMConfiguration();
        if (remaining.startsWith("events")) {
            configuration.setEventListenerType(remaining.split(":")[1]);
        } else {        
            configuration.setConnectionURL(new URL(remaining));
        }
        JBPMEndpoint endpoint = new JBPMEndpoint(uri, this, configuration);
        setProperties(endpoint, parameters);
        return endpoint;
    }

}
